==> 1.5.zip: hanoi-towers/README.md <==
# Welcome to the Hanoi Towers!
# ![Hanoi Towers Logo](/source/res/icon.png)

***************************
[![Snap Status](https://build.snapcraft.io/badge/QuasarApp/Hanoi-Towers.svg)](https://build.snapcraft.io/user/QuasarApp/Hanoi-Towers)
***************************
## What is Hanoi Towers
The Hanoi Tower is one of the most popular puzzles of the 19th century. Three bars are given, on one of which eight rings are strung, the rings differ in size and smaller. The problem is to transfer the pyramid from the eight rings for the least number of moves to another rod. At a time, only one ring is allowed to carry, and you can not put a larger ring on less

supported platform: 
1. Linux
2. Android 
3. Windows 

## Build for Linux (snap)

  -  sudo apt install git snapcraft 
  -  git clone https://github.com/EndrII/Hanoi-Towers.git
  -  cd Hanoi-Towers
  -  snapcraft


## Build Windows 
* donwload [qt creator](https://www.qt.io/download-thank-you?os=windows)
* install qt 5.9.x or later
* build release version
* use [qt win deploy](http://doc.qt.io/qt-5/windows-deployment.html)

## Build Android 
* donwload [qt creator](https://www.qt.io/download-thank-you?os=windows)
* install qt 5.9.x or later
* install android sdk and ndk
* install jdk

## Install 
You can download the latest version of the game [here](https://github.com/EndrII/Hanoi-Towers/releases).

Or download from official services
  * [Android](https://play.google.com/store/apps/details?id=df.mobily.hanoi_towers) 
  * [Ubuntu](https://uappexplorer.com/snap/ubuntu/hanoi-towers)
  * Windows - this application has not supported windows store

## Donate
If you want to help the project, then you can donate a small amount to our bitcoin wallet.

### Bitcoin address - 1NJNbDKmezcUcHRfzpBeq2fHeG21oEKX8Q

==> 1.5.3.3.zip: hanoi-towers/README.md <==
# Hanoi Towers [![hanoi-tower](https://snapcraft.io/hanoi-tower/badge.svg)](https://snapcraft.io/hanoi-tower)

# ![Hanoi Towers Logo](hanoi_towers/res/HanoiTowers_Banner_Web.png)

***************************
## What is Hanoi Towers

The Hanoi Tower is one of the most popular puzzles of the 19th century. Three bars are given, on one of which eight rings are strung, the rings differ in size and smaller. The problem is to transfer the pyramid from the eight rings for the least number of moves to another rod. At a time, only one ring is allowed to carry, and you can not put a larger ring on less

## Screenshots
![scrin1](Screenshots/S80715-112600.jpg)
![scrin2](Screenshots/S80715-112606.jpg)
![scrin3](Screenshots/S80715-112622.jpg)
![scrin4](Screenshots/S80715-112645.jpg)
![scrin5](Screenshots/S80715-112656.jpg)

## supported platform: 
1. Linux
2. Android 
3. Windows 


## Install 
You can download the latest version of the game [here](https://github.com/EndrII/Hanoi-Towers/releases).

Or download from official services
  * [Android](https://play.google.com/store/apps/details?id=df.mobily.hanoi_towers) 
  * [Ubuntu](https://snapcraft.io/hanoi-tower)
  * Windows - this application has not supported windows store

[![Get it from the Snap Store](https://snapcraft.io/static/images/badges/en/snap-store-black.svg)](https://snapcraft.io/hanoi-tower)

## Donate
If you want to help the project, then you can donate a small amount to our bitcoin wallet.

### Bitcoin address - 1NJNbDKmezcUcHRfzpBeq2fHeG21oEKX8Q
